SU2xSU2 package
===============


SU2xSU2.SU2\_mat\_routines module
---------------------------------

.. automodule:: SU2xSU2.SU2_mat_routines
   :members:
   :undoc-members:
   :show-inheritance:

SU2xSU2.SU2xSU2 module
----------------------

.. automodule:: SU2xSU2.SU2xSU2
   :members:
   :undoc-members:
   :special-members: __init__
   :show-inheritance:

SU2xSU2.analysis module
-----------------------

.. automodule:: SU2xSU2.analysis
   :members:
   :undoc-members:
   :show-inheritance:

SU2xSU2.calibrate\_paras module
-------------------------------

.. automodule:: SU2xSU2.calibrate_paras
   :members:
   :undoc-members:
   :show-inheritance:

SU2xSU2.correlations module
---------------------------

.. automodule:: SU2xSU2.correlations
   :members:
   :undoc-members:
   :show-inheritance:

SU2xSU2.plotting module
-----------------------

.. automodule:: SU2xSU2.plotting
   :members:
   :undoc-members:
   :show-inheritance:
